Reference
=========

.. currentmodule:: pipcs
.. autosummary::
   :nosignatures:

   Config
   Choices
   Condition
   required
   InvalidChoiceError
   RequiredError

.. autoclass:: Config
               :members:
               :exclude-members: update
.. autoclass:: Choices
               :members:
.. autoclass:: Condition
               :members:
.. autoclass:: required
               :members:
.. autoclass:: InvalidChoiceError
               :members:
.. autoclass:: RequiredError
               :members:
